"applyToTokenizedDocumentViewTokens" <-
# Applies the given function to the tokens in the given tokenizedDocumentView
# object and returns a new tokenizedDocumentView object containing the
# values returned by the given function.
function(object, f) {
    tokens <- tokens(object)
    newTokens <- f(tokens)
    view <- TokenizedDocumentView(document=document(object), tokens=newTokens)
    return(view)
}
setMethod("applyToTokens", 
    signature(object="TokenizedDocumentView", f="function"),
    applyToTokenizedDocumentViewTokens)


"applyToTokenizedCorpusViewTokens" <-
# Applies the given function to the tokens in the given tokenizedCorpusView
# object and returns a new tokenizedCorpusView object containing the
# values returned by the given function.
function(object, f) {
    objCorpus <- corpus(object)
    tdViews <- documentViews(object)
    for (docId in names(tdViews)) {
        tdView <- tdViews[[docId]]
        newTDView <- applyToTokens(tdView, f)
        tdViews[[docId]] <- newTDView
    }
    return(TokenizedCorpusView(objCorpus, tdViews))
}
setMethod("applyToTokens",
    signature(object="TokenizedCorpusView", f="function"),
    applyToTokenizedCorpusViewTokens)


"applyToDocumentOrCorpusTokens" <-
# Tokenizes the given document or corpus with the default tokenizer, then 
# applies the given function to the tokens.
function(object, f) {
    return(applyToTokens(tokenize(object), f))
}
setMethod("applyToTokens", 
    signature(object="Document", f="function"), applyToDocumentOrCorpusTokens)
setMethod("applyToTokens", 
    signature(object="Corpus", f="function"), applyToDocumentOrCorpusTokens)
