# document - A simple class for representing a document.

setClass("Document",
    representation(
        id      =   "character",
        content =   "character"
    )
)

"isValidDocument" <-
# Returns TRUE if the given document object is valid, otherwise returns a
# character error message. A valid document object has an id and content of
# length 1 and an id with nchar > 0.
function (object) {

    objectId <- id(object)
    objectContent <- content(object)

    if (length(objectId) != 1) {
        return("must have id with length 1")
    }

    if (nchar(objectId) < 1) {
        return("must have nchar > 0")
    }

    if (length(objectContent) != 1) {
        return("must have content with length 1")
    }

    return(TRUE)

}
setValidity("Document", isValidDocument)


"getDocumentContent" <-
# Returns the content of the given document
function(object) {
    return(object@content)
}
setMethod("content", "Document", getDocumentContent)


"setDocumentContent" <-
# Sets the content of the given document to the given value
function(object, value) {
    if (length(value) == 1) {
        object@content <- value
        return(object)
    } else {
        stop("new content must have length 1")
    }
}
setMethod("content<-", signature(object="Document", value="character"),
    setDocumentContent)


"getDocumentId" <-
# Returns the id of the given document
function(object) {
    return(object@id)
}
setMethod("id", "Document", getDocumentId)


"setDocumentId" <-
# Sets the id of the given document
function(object, value) {
    if (length(value) == 1 && nchar(value) > 0) {
        object@id <- value
        object
    } else {
        stop("new id must have length 1 and nchar > 0")
    }
}
setMethod("id<-", signature(object="Document", value="character"), 
    setDocumentId)

"Document" <-
# Constructs a new document using the given id and content
function(id, content) {
    d <- new("Document", id=id, content=content)
    return(d)
}

