"filterTokenizedDocumentViewTokens" <-
# Filters the tokens of the given tokenizedDocumentView by the given function.
# Returns a new tokenizedDocumentView containing only the tokens such that
# f(token) is TRUE. 
function(object, f, negate=FALSE) {
    
    fn <- f
    if (negate) {
        fn <- function(x) !f(x)
    }

    tokens <- tokens(object)
    newTokens <- tokens[ fn(tokens) ]
    view <- TokenizedDocumentView(document=document(object), tokens=newTokens)
    return(view)
}
setMethod("filterTokens",
    signature(object="TokenizedDocumentView", f="function"),
    filterTokenizedDocumentViewTokens)


"filterTokenizedCorpusViewTokens" <-
# Filters the tokens of the given tokenizedCorpusView by the given function.
# Returns a new tokenizedCorpusView containing only the tokens such that
# f(token) is TRUE. 
function(object, f, negate=FALSE) {
    objCorpus <- corpus(object)
    tdViews <- documentViews(object)
    for (docId in names(tdViews)) {
        tdView <- tdViews[[docId]]
        newTDView <- filterTokens(tdView, f, negate)
        tdViews[[docId]] <- newTDView
    }
    return(TokenizedCorpusView(objCorpus, tdViews))
}
setMethod("filterTokens",
    signature(object="TokenizedCorpusView", f="function"),
    filterTokenizedCorpusViewTokens)


"filterTokensDocumentOrCorpus" <-
# Filters the tokens in the given document or corpus with the given function,
# first tokenizing using the default tokenizer
function(object, f, negate=FALSE) {
    return(filterTokens(tokenize(object), f, negate))
}
setMethod("filterTokens",
    signature(object="Document", f="function"),
    filterTokensDocumentOrCorpus)
setMethod("filterTokens",
    signature(object="Corpus", f="function"),
    filterTokensDocumentOrCorpus)

