"filterDf" <-
# Filters out tokens based on the number of documents they appear in.
# Takes three arguments: a tokenized corpus view, min, and max. 
# If min and max are less than one, they are interpreted as a fraction
# of the total number of documents. If they are greater than or equal to one, 
# they are interpreted as the min/max number of documents.
# A token that satisfies
#       min <= df(token) <= max
# is kept in the TokenizedCorpusView.
function(object, min=1, max=Inf) {

    nDocs <- length(corpus(object))

    if (min < 1) {
        min <- nDocs * min
    }

    if (max < 1) {
        max <- nDocs * max
    }

    dfVec <- df(object)
    fn <- function(x) {
        vec <- dfVec[x]
        return( min <= vec & vec <= max ) 
    }

    return(filterTokens(object, fn))

}
setMethod("filterTokensDf", signature(object="TokenizedCorpusView"), 
    filterDf)
