"readFromText" <-
# Reads a plain text file into a document object. If an "id" argument
# is not given, sets the id of the resulting document using the
# description property of the src.
function (src, format, ...) {

    dots <- list(...)

    # Turn src into a connection object if necessary

    if (is.character(src)) {
        src <- file(src)
    }
    if (!inherits(src, "connection")) {
        stop("'file' must be a character string or connection")
    }
    if (!isOpen(src, "r")) {
        open(src, "r")
        on.exit(close(src))
    }

    contentVal <- paste(readLines(src, warn=FALSE), collapse="\n")
    idVal <- ""
    if (hasArg("id")) {
        idVal <- dots$id
    } else {
        idVal <- summary(src)$description
    }

    return( Document(id=idVal, content=contentVal) )

}
setMethod("readDocument", signature(format="TextDocumentReader"),
  readFromText)

# If the format option is missing, assume that we are reading in text
setMethod("readDocument", signature(format="missing"),
    function(src, format, ...) {
        return(readDocument(src, TextDocumentReader(), ...))
    }
)

