# XXX We can probably come up with a better default regex
DEFAULT_TAGGER_REGEX <- list(
  list('^-?[0-9]+(.[0-9]+)?$', 'CD'),   # cardinal numbers
  list('^(The|the|A|a|An|an)$', 'AT'),  # articles
  list('.*able$', 'JJ'),                # adjectives
  list('.*ness$', 'NN'),                # nouns formed from adjectives
  list('.*ly$', 'RB'),                  # adverbs
  list('.*s$', 'NNS'),                  # plural nouns
  list('.*ing$', 'VBG'),                # gerunds
  list('.*ed$', 'VBD'),                 # past tense verbs
  list('.*', 'NN')                      # nouns (default)
)


# A tagger that attempts to associate tokens with tags given a set of
# regex-tag pairs, given as a nested list, where each sublist is a
# regex/tag pair.  Also takes an optional backoff tagger, which is
# used to tag tokens for which the current tagger always agrees with
# the backoff, or for which it provides no tag.  This class wraps an
# underlying nltk regexptagger.
setClass("RegexTagger",
    representation(
      pattern = "list",     # a list or regex-tag pairs
      pointer = "externalptr",  # external ptr to ntlk object
      backoff = "Tagger", # the backoff tagger (XXX ref eventually)
      "WrappedTagger"              # extends the tagger virtual class
    ),
)

"isValidRegexTagger" <-
# A valid RegexTagger should have a pattern vector which is a
# character vector of even length
function(object) {
  pattern <- pattern(object)
  for (i in 1:length(pattern)) {
    if (length(pattern[[i]]) != 2)
      return("patterns must be pairs")
  }

  return(TRUE)
}
setValidity("RegexTagger", isValidRegexTagger)

# Access the tag of the given RegexTagger
setMethod("pattern", "RegexTagger", 
  function(object) {
    return(object@pattern)
  }
)
  
# Access the backoff tagger of the given RegexTagger
setMethod("backoff", "RegexTagger",
  function(object) {
    return(object@backoff)
  }
)

# A constructor for RegexTaggers
RegexTagger <- function(pattern = DEFAULT_TAGGER_REGEX,   
                        backoff = NullTagger()) 
{
  bptr <- NULL
  if (! is(backoff, "Tagger"))
      error("backoff must be of type Tagger")
  else if (! is(backoff, "NullTagger"))
    bptr <- backoff@pointer

  ptr <- .Call("construct_regexp_tagger", pattern, bptr)
  return(new("RegexTagger", pattern = pattern, pointer = ptr,
             backoff = backoff))
}
