# Taken from NLTK
defaultPattern <- "\\w+|[^\\w\\s]+"

setClass("RegexTokenizer",
    representation(
        pattern     = "character",
        matchToken  = "logical",
        "Tokenizer"
    ),
    prototype(
        pattern     = defaultPattern,
        matchToken  = TRUE
    )
)


"isValidRegexTokenizer" <-
# A valid regexTokenizer object should have a single regex pattern and a
# single matchToken value
function(object) {
    thisPattern <- pattern(object)
    thisMatchToken <- matchToken(object)

    if (length(thisPattern) != 1) {
        return("pattern must have length 1")
    }
    if (length(thisMatchToken) != 1) {
        return("matchToken must have length 1")
    }
    return(TRUE)
}
setValidity("RegexTokenizer", isValidRegexTokenizer)


"getRegexTokenizerPattern" <-
# Returns the pattern of the given regexTokenizer object
function(object) {
    return(object@pattern)
}
setMethod("pattern", "RegexTokenizer", getRegexTokenizerPattern)


"setRegexTokenizerPattern" <-
# Sets the pattern of the given regexTokenizer object to the given value
function(object, value) {
    object@pattern <- value
    return(object)
}
setMethod("pattern<-", signature(object="RegexTokenizer"), 
    setRegexTokenizerPattern)


"getRegexTokenizerMatchToken" <- 
# Returns TRUE if the given regexTokenizer matches tokens, FALSE if it matches
# separators.
function(object) {
    return(object@matchToken)
}
setMethod("matchToken", "RegexTokenizer", getRegexTokenizerMatchToken)


"setRegexTokenizerMatchToken" <-
# Sets whether the given regexTokenizer matches tokens (TRUE) or separators
# (FALSE).
function(object, value) {
    object@matchToken <- value
    return(object)
}
setMethod("matchToken<-", signature(object="RegexTokenizer", value="logical"),
    setRegexTokenizerMatchToken)


"RegexTokenizer" <-
# Creates a new regexTokenizer
function(pattern=defaultPattern, matchToken=TRUE) {
    return(new("RegexTokenizer", pattern=pattern, matchToken=matchToken))
}

