"showDocument" <-
# shows the content of the given document
function(object) {
    cat(paste("Document:", id(object), "\n"))
    cat(paste(content(object), "\n"))
}
setMethod("show", "Document", showDocument)


"showTextDocumentReader" <-
# prints "textDocumentReader" since textDocumentReaders have no representation
function(object) {
    print("TextDocumentReader")
}
setMethod("show", "TextDocumentReader", showTextDocumentReader)


"showTokenizedDocumentView" <-
# Prints some information about this view to the screen
function(object) {
    name <- id(document(object))
    nTokens <- length(tokens(object))
    nUniqueTokens <- length(unique(object))

    str <- paste("A tokenized document view of", name, "with", nTokens, 
                 "total tokens and", nUniqueTokens, "unique tokens\n")
    cat(str)
}
setMethod("show", "TokenizedDocumentView", showTokenizedDocumentView)

"showTaggedDocumentView" <-
# Prints some information about this view to the screen
function(object) {
    name <- id(document(object))
    nTTs <- length(taggedTokens(object))
    nUniqueTokens <- length(uniqueTokens(object))
    nUniqueTags <- length(uniqueTags(object))
    nUniqueTTs <- length(unique(object))

    str <- paste("A tagged document view of", name, "with", nTTs, 
                 "total tagged tokens,", nUniqueTTs,
                 "unique tagged tokens,", nUniqueTokens, 
                 "unique tokens, and", nUniqueTags, "unique tags\n")
    cat(str)
}
setMethod("show", "TaggedDocumentView", showTaggedDocumentView)

"showCorpus" <- 
# Prints out the corpus id and the ids of the documents
function(object) {
    cId <- id(object)
    docs <- documents(object)
    cat(paste("Corpus:", cId, "\n"))
    cat("Documents:\n\n")
    for (doc in docs) {
        dId <- id(doc)
        cat(paste(dId, "\n"))
    }
}
setMethod("show", "Corpus", showCorpus)


"showTokenizedCorpusView" <-
# prints out the corpus id, total number of tokens, and total number of 
# unique tokens
function(object) {
    objCorpus <- corpus(object)
    cId <- id(objCorpus)
    nUnique <- length(unique(object))
    nTotal <- sum(documentTokenMatrix(object))

    str <- paste("A tokenized corpus view of", cId, "with", nTotal, 
                 "total tokens and", nUnique, "unique tokens\n")
    cat(str)

}
setMethod("show", "TokenizedCorpusView", showTokenizedCorpusView)

"showTaggedCorpusView" <-
# prints out the corpus id, total number of tokens, total number of 
# unique tokens, etc
function(object) {
    objCorpus <- corpus(object)
    cId <- id(objCorpus)
    nUniqueTok <- length(uniqueTokens(object))
    nUniqueTag <- length(uniqueTags(object))
    nUniqueTT <- length(unique(object))
    nTotalTT <- sum(documentTaggedTokenMatrix(object))

    str <- paste("A tokenized corpus view of", cId, "with", nTotalTT,
                 "total tagged tokens,", nUniqueTT, 
                 "unique tagged tokens,", nUniqueTok, 
                 "unique tokens, and", nUniqueTag, "unique tags\n")
    cat(str)

}
setMethod("show", "TaggedCorpusView", showTaggedCorpusView)
