# snowballStemmer - a stemmer class built around the Rstem package

#source(system.file("R/stemmer-class.R", package="text2num"))

library(Rstem)

setClass("SnowballStemmer",
    representation(
        "Stemmer",
        language = "character"
    ),
    prototype(
        language = "english"
    )
)


getSnowballStemmerLanguage <-
# Returns the language of the given stemmer
function(object) {
    return(object@language)
}
setMethod("language", "SnowballStemmer", getSnowballStemmerLanguage)


isValidSnowballStemmer <-
# A valid snowballStemmer must have its language slot set to a language that
# is in the list returned by the getStemLanguages() function in the 
# Rstem package.
function(object) {
    stemLanguages <- getStemLanguages()
    thisLanguage <- language(object)
    if (thisLanguage %in% stemLanguages) {
        return(TRUE)
    } else {
        return("language must be in the Rstem package's getStemLanguages()")
    }
}
setValidity("SnowballStemmer", isValidSnowballStemmer)


"SnowballStemmer" <- 
# constructs a new snowballStemmer object
function(language="english") {
    return(new("SnowballStemmer", language=language))
}
