library(Rstem)

"snowballStemChar" <-
# Stems the given character using the given snowballStemmer and given
# tokenizer. If object has length 1, it will be tokenized first using the
# tokenizer. If it has length != 1, it will be treated as already tokenized.
function(object, stemmer, tokenizer) {
    tokens <- NULL
    if (length(object) == 1) {
        tokens <- tokenize(object, tokenizer)
    } else {
        tokens <- object
    }
    lang <- language(stemmer)
    return(wordStem(tokens, language=lang))
}
setMethod("stem", 
    signature(object="character", stemmer="SnowballStemmer", 
        tokenizer="Tokenizer"), 
    snowballStemChar)

"stemTokenizedView" <-
# Stems the tokens of the given TokenizedDocumentView or TokenizedCorpusView
function(object, stemmer, tokenizer) {
    stemFunction <- function(x) {
        return(stem(x, stemmer))
    }
    return(applyToTokens(object, stemFunction))
}
setMethod("stem", 
    signature(
        object="TokenizedDocumentView", 
        stemmer="Stemmer", 
        tokenizer="Tokenizer"), 
    stemTokenizedView)

setMethod("stem", 
    signature(
        object="TokenizedCorpusView", 
        stemmer="Stemmer", 
        tokenizer="Tokenizer"), 
    stemTokenizedView)


"stemTokenizableObject" <-
# Stems the tokens of the given Document or Corpus object and returns
# it as a TokenizedDocumentView or TokenizedCorpusView object.
function(object, stemmer, tokenizer) {
    tobject <- tokenize(object, tokenizer)
    return(stem(tobject, stemmer, tokenizer))
}

setMethod("stem", 
    signature(
        object="Document",
        stemmer="Stemmer",
        tokenizer="Tokenizer"), 
    stemTokenizableObject)

setMethod("stem", 
    signature(
        object="Corpus", 
        stemmer="Stemmer", 
        tokenizer="Tokenizer"), 
    stemTokenizableObject)

setMethod("stem", 
    signature(
        object="character", 
        stemmer="Stemmer", 
        tokenizer="Tokenizer"), 
    stemTokenizableObject)


# Makes snowballStemmer the default stemmer and regexTokenizer the default
# tokenizer.

setMethod("stem", signature(stemmer="missing", tokenizer="missing"),
    function(object, stemmer, tokenizer) {
        stemmer <- SnowballStemmer()
        tokenizer <- RegexTokenizer()
        return(stem(object, stemmer, tokenizer))
    }
)
setMethod("stem", signature(stemmer="missing", tokenizer="Tokenizer"),
    function(object, stemmer, tokenizer) {
        stemmer <- SnowballStemmer()
        return(stem(object, stemmer, tokenizer))
    }
)
setMethod("stem", signature(stemmer="Stemmer", tokenizer="missing"),
    function(object, stemmer, tokenizer) {
        tokenizer <- RegexTokenizer()
        return(stem(object, stemmer, tokenizer))
    }
)
