setClass("TaggedCorpusView",
    representation(
        "TokenizedCorpusView",
        uniqueTags              =   "character",
        uniqueTokenTags         =   "character",
        documentTagMatrix       =   "matrix",
        documentTokenTagMatrix  =   "matrix"
    )
)


"getTaggedCorpusViewUniqueTaggedTokens" <-
# Returns the unique token-tag pairs in this view
function(x, incomparables="missing") {
    return(x@uniqueTokenTags)
}
setMethod("unique", "TaggedCorpusView",
    getTaggedCorpusViewUniqueTaggedTokens)

setMethod("uniqueTokens", "TaggedCorpusView",
    getTokenizedCorpusViewUniqueTokens)

"getTaggedCorpusViewUniqueTags" <-
# Returns the unique tags in this view
function(object) {
  return(object@uniqueTags)
}
setMethod("uniqueTags", "TaggedCorpusView",
  getTaggedCorpusViewUniqueTags)

# Inherits documentTokenMatrix from tokenizedCorpusView


"getTaggedCorpusViewDTMatrix" <-
# Returns the document-tag matrix of this view
function(object) {
    return(object@documentTagMatrix)
}
setMethod("documentTagMatrix", "TaggedCorpusView", 
    getTaggedCorpusViewDTMatrix)

"getTaggedCorpusViewDTTMatrix" <-
# Returns the document-tag matrix of this view
function(object) {
    return(object@documentTokenTagMatrix)
}
setMethod("documentTaggedTokenMatrix", "TaggedCorpusView", 
    getTaggedCorpusViewDTTMatrix)

# Inherits documentViews from TokenizedCorpusView

# XXX Need to write a validity tester


# XXX this should probably be a method to get type checking
"TaggedCorpusView" <-
# Constructs a new TaggedCorpusView from the given taggedDocumentViews.
function(corpus, taggedDocumentViews) {

    nDocs <- length(corpus)
    docIds <- character(nDocs)

    newTokens <- character()
    newTags <- character()
    newTTs <- character()
    for (i in 1:nDocs) {

        tdv <- taggedDocumentViews[[i]]
        docIds[i] <- id(document(tdv))

        newTokens <- unique(append(newTokens, uniqueTokens(tdv)))
        newTags <- unique(append(newTags, uniqueTags(tdv)))
        newTTs <- unique(append(newTTs, unique(tdv)))
        

    }


    nTokens <- length(newTokens)
    nTags <- length(newTags)
    nTTs <- length(newTTs)

    tokMatrix <- matrix(0, nrow=nDocs, ncol=nTokens)
    rownames(tokMatrix) <- docIds
    colnames(tokMatrix) <- newTokens

    tagMatrix <- matrix(0, nrow=nDocs, ncol=nTags)
    rownames(tagMatrix) <- docIds
    colnames(tagMatrix) <- newTags

    ttMatrix <- matrix(0, nrow=nDocs, ncol=nTTs)
    rownames(ttMatrix) <- docIds
    colnames(ttMatrix) <- newTTs

    for (i in 1:nDocs) {
        tdv <- taggedDocumentViews[[i]]
        docId <- docIds[i]

        toktbl <- tokenFreqTable(tdv)
        tagtbl <- tagFreqTable(tdv)
        tttbl <- freqTable(tdv)
        
        rowTokens <- names(toktbl)
        rowTags <- names(tagtbl)
        rowTTs <- names(tttbl)

        tokfreqs <- as.vector(toktbl)
        tagfreqs <- as.vector(tagtbl)
        ttfreqs <- as.vector(tttbl)

        tokMatrix[docId, rowTokens] <- tokfreqs
        tagMatrix[docId, rowTags] <- tagfreqs
        ttMatrix[docId, rowTTs] <- ttfreqs

    }

    obj <- new("TaggedCorpusView", corpus=corpus, 
               uniqueTokens=newTokens, documentTokenMatrix=tokMatrix, 
               tokenizedDocumentViews=taggedDocumentViews,
               uniqueTags=newTags, uniqueTokenTags=newTTs,
               documentTagMatrix=tagMatrix, 
               documentTokenTagMatrix=ttMatrix)
    return(obj)
    
}
