setClass("TokenizedCorpusView",
    representation(
        "CorpusView",
        corpus                  =   "Corpus",
        uniqueTokens            =   "character",
        documentTokenMatrix     =   "matrix",
        tokenizedDocumentViews  =   "list"
    )
)


"getTokenizedCorpusViewUniqueTokens" <-
# Returns the unique tokens in this view
function(x, incomparables="missing") {
    return(x@uniqueTokens)
}
setMethod("unique", "TokenizedCorpusView",
    getTokenizedCorpusViewUniqueTokens)


"getTokenizedCorpusViewDTMatrix" <-
# Returns the document-token matrix of this view
function(object) {
    return(object@documentTokenMatrix)
}
setMethod("documentTokenMatrix", "TokenizedCorpusView", 
    getTokenizedCorpusViewDTMatrix)


"getTokenizedCorpusViewDocViews" <-
# Returns the tokenizedDocumentViews of the underlying documents
function(object) {
    return(object@tokenizedDocumentViews)
}
setMethod("documentViews", "TokenizedCorpusView", 
    getTokenizedCorpusViewDocViews)


"isValidTokenizedCorpusView" <-
function(object) {
    
    objCorpus <- corpus(object)
    objUniqueTokens <- unique(object)
    objDTMatrix<- documentTokenMatrix(object)
    objTDViews <- documentViews(object) 

    # XXX Fix this later
    #if (length(corpus) != length(objTDViews)) {
    #    return("corpus must have same length as list of documentViews")
    #}

    r <- nrow(objDTMatrix)
    c <- ncol(objDTMatrix)
    lc <- length(objCorpus)
    lt <- length(objUniqueTokens)

    if (r != lc || c != lt) {
        msg <- paste("documentTokenMatrix must have dimensions equal to nDocs",
                     "and nUniqueTokens - got", lc, lt, "should be", r, c)
        return(msg)
    }

    tdvNames <- names(objTDViews)
    for (tdvName in tdvNames) {
        tdv <- objTDViews[[tdvName]]
        if (is(tdv, "TokenizedDocumentView")) {
            docId <- id(document(tdv))
            if (tdvName != docId) {
                msg <- paste(tdvName, "does not match document id", docId)
                return(msg)
            }
        } else {
            msg <- paste("object", tdv, "not a tokenizedDocumentView")
            return(msg)
        }
    }

    return(TRUE)
    
}
setValidity("TokenizedCorpusView", isValidTokenizedCorpusView)


"TokenizedCorpusView" <-
# Constructs a new TokenizedCorpusView from the given tokenizedDocumentViews.
function(corpus, tokenizedDocumentViews) {

    nDocs <- length(corpus)
    docIds <- character(nDocs)

    newTokens <- character()
    for (i in 1:nDocs) {

        tdv <- tokenizedDocumentViews[[i]]
        docIds[i] <- id(document(tdv))

        newTokens <- unique(append(newTokens, unique(tdv)))

    }


    nTokens <- length(newTokens)

    dtMatrix <- matrix(0, nrow=nDocs, ncol=nTokens)
    rownames(dtMatrix) <- docIds
    colnames(dtMatrix) <- newTokens

    for (i in 1:nDocs) {
        tdv <- tokenizedDocumentViews[[i]]
        docId <- docIds[i]

        tbl <- freqTable(tdv)
        rowTokens <- names(tbl)
        freqs <- as.vector(tbl)

        dtMatrix[docId, rowTokens] <- freqs

    }

    obj <- new("TokenizedCorpusView", corpus=corpus, uniqueTokens=newTokens,
        documentTokenMatrix=dtMatrix, 
        tokenizedDocumentViews=tokenizedDocumentViews)
    return(obj)
    
}

"getTokenizedCorpusViewDTTMatrix" <-
# Returns the DT matrix weighted by idf values
function(object) {
    dtm <- documentTokenMatrix(object)
    idfvec <- idf(object)
    return( t( t(dtm) * idfvec ) )
}
setMethod("documentTokenTfidfMatrix", "TokenizedCorpusView",
    getTokenizedCorpusViewDTTMatrix)

"tokenizedCorpusViewHas" <-
# Returns TRUE if this contains the given token
function(object, container, ...) {
    return(object %in% unique(container))
}
setMethod("has", 
    signature(object="character", container="TokenizedCorpusView"),
    tokenizedCorpusViewHas)

