# TokenizedDocumentView - A view of a document as a sequence of tokens.
setClass("TokenizedDocumentView",
    representation(
        "DocumentView",
        tokens          =   "character",
        tokenFreqTable  =   "table",
        uniqueTokens    =   "character"
    )
)

"isValidTokenizedDocumentView" <-
# A valid tokenizedDocumentView must have no empty strings in the token vector
function(object) {
    if (any("" == tokens(object))) {
        return("empty string must not be in token vector")
    }
    return(TRUE)
}
setValidity("TokenizedDocumentView", isValidTokenizedDocumentView)


"getTokenizedDocumentViewTokens" <-
# Returns the tokens of this TokenizedDocumentView
function(object) {
    return(object@tokens)
}
setMethod("tokens", "TokenizedDocumentView", getTokenizedDocumentViewTokens)


"TokenizedDocumentView" <-
# Constructs a new TokenizedDocumentView
function(document, tokens, tokenFreqTable=NULL) {

    if (is.null(tokens)) {
        tokens <- character(0)
    }

    if (is.null(tokenFreqTable)) {
        tokenFreqTable <- table(tokens)
    }

    uniqueTokens <- row.names(tokenFreqTable)
    if (is.null(uniqueTokens)) {
        uniqueTokens <- character(0)
    }

    res <- new("TokenizedDocumentView", 
        document=document, tokens=tokens, 
        tokenFreqTable=tokenFreqTable, 
        uniqueTokens=uniqueTokens)
    return(res)
}


"tokenizedDocumentViewExtract" <-
# Returns the tokens at the given indices
function(x, i, j, drop) {
    if (!missing(j)) {
        warning("second argument to extractor function ignored")
    }

    subTokens <- tokens(x)[i]

    return(subTokens)
    
} 
setMethod("[", signature(x="TokenizedDocumentView"), 
    tokenizedDocumentViewExtract)


"getTokenizedDocumentViewFreqTable" <-
# Returns the frequency table of tokens
function(object, ...) {
    return(object@tokenFreqTable)
}
setMethod("freqTable", "TokenizedDocumentView", 
    getTokenizedDocumentViewFreqTable)


"getTokenizedDocumentViewUniqueTokens" <-
# Returns the unique tokens
function(x, incomparables="missing") {
    return(x@uniqueTokens)
}
setMethod("unique", "TokenizedDocumentView", 
    getTokenizedDocumentViewUniqueTokens)


"tokenizedDocumentViewHas" <-
# Returns TRUE if this contains the given token
function(object, container, ...) {
    return(object %in% unique(container))
}
setMethod("has", 
    signature(object="character", container="TokenizedDocumentView"),
    tokenizedDocumentViewHas)


"getTokenizedDocumentViewTokenFreq" <-
# Returns the frequency of the given token
function(object, container, ...) {
    if (has(object, container)) {
        return(freqTable(container)[[object]])
    } else {
        return(0)
    }
}
setMethod("freq", 
    signature(object="character", container="TokenizedDocumentView"),
    getTokenizedDocumentViewTokenFreq)



