# A tagger that associates words with their most likely tags in a
# training corpus and uses this info to tag novel text.  Also takes an
# optional backoff tagger, which is used to tag tokens for which the
# current tagger always agrees with the backoff, or for which it
# provides no tag.  This class wraps an underlying nltk unigramtagger.
setClass("UnigramTagger",
    representation(
      pointer = "externalptr",  # external ptr to ntlk object
      backoff = "Tagger",   # the backoff tagger (XXX ref eventually)
      "WrappedTagger"       # extends the tagger virtual class
    ),
)

"isValidUnigramTagger" <-
function(object) {
  return(TRUE)
}
setValidity("UnigramTagger", isValidUnigramTagger)

# Access the backoff tagger of the given UnigramTagger
setMethod("backoff", "UnigramTagger",
  function(object) {
    return(object@backoff)
  }
)

"goodTaggedSentenceList" <-
# Function to make sure a training set in nested list form is
# formatted correctly
function(tslist) {
  lapply(tslist, function (sublist) {
    if (! is.list(sublist))
      return(FALSE)
    lapply(sublist, function(pairlist) {
      if (! is.list(pairlist))
        return(FALSE)
      if (length(pairlist) != 2)
        return(FALSE)
      if (! is.character(pairlist[[1]]))
        return(FALSE)
      if (! is.character(pairlist[[2]]))
        return(FALSE)
     })
   })

   return(TRUE)
}

# A series of constructors for unigram taggers for different types of
# training sets

# XXX TODO
# Plain character version that splits tags and sentences.
# TaggedDocumentView and TaggedCorpusView versions.
# Whatever type we end up using to deal with pre-split sentences.

# Constructor for trainset as nested list where token-tag pairs are
# nested within sentences.
setMethod("UnigramTagger", signature(trainset = "list", 
                                     backoff = "Tagger"),
  function(trainset, backoff = NullTagger()) {
    bptr <- NULL
    if (! is(backoff, "Tagger"))
        error("backoff must be of type Tagger")
    else if (! is(backoff, "NullTagger"))
      bptr <- backoff@pointer
  
    if (! goodTaggedSentenceList(trainset))
      stop("Training list format is bad")

    ptr <- .Call("construct_unigram_tagger", trainset, bptr)
    return(new("UnigramTagger", pointer = ptr, backoff = backoff))
  }
)
