"testRegexTokenizeChar" <- function() {

    str <- "This is a test string. With punctuation!"

    # Default tokenizer
    expected1 <- c("This", "is", "a", "test", "string", ".", "With",
        "punctuation", "!")
    checkEquals(tokenize(str), expected1, "default settings")

    # Tokenize on spaces
    t <- RegexTokenizer("\\s+", matchToken=FALSE)
    expected2 <- c("This", "is", "a", "test", "string.", "With",
        "punctuation!")
    checkEquals(tokenize(str, t), expected2, "tokenize on gaps")


    # Should remove empty strings from token list
    str2 <- "xxy"
    expected3 <- c("y")
    checkEquals(tokenize(str2, RegexTokenizer("x", FALSE)), expected3,
        "remove empty strings")

}


"testTokenizeDocument" <- function() {

    sentFile <- system.file("samples/en/sentence.txt", package="text2num")
    doc <- readDocument(sentFile)

    # Make sure that the tokens in a TokenizedDocumentView are the same
    # as the tokenized string of the content
    txt <- content(doc)
    txtTokens <- tokenize(txt)
    tdoc <- tokenize(doc)
    checkEquals(tokens(tdoc), txtTokens, "tokenized doc same as tokenized str")

    checkTrue(is(tdoc, "TokenizedDocumentView"), "is TokenizedDocumentView")

    # with a custom tokenizer
    t <- RegexTokenizer("o", matchToken=FALSE)
    txtTokens2 <- tokenize(txt, t)
    tdoc2 <- tokenize(doc, t)
    checkEquals(tokens(tdoc2), txtTokens2, 
        "tokenized doc same as tokenized str with given tokenizer")

    
    # should be able to tokenize an empty doc
    emptyDoc <- Document("id", "")
    temptyDoc <- tokenize(emptyDoc)
    checkEquals(tokens(temptyDoc), tokenize(""), "tokenize empty doc")

}


"testTokenizeCorpus" <- function() {

    reader <- DirectoryCorpusReader(pattern="anna\\.txt|hero\\.txt")
    dir <- system.file("samples/en/", package="text2num")
    corp <- readCorpus(dir, reader)

    t <- RegexTokenizer("o", matchToken=FALSE)

    docs <- documents(corp)
    tdocs <- list()
    tdocs2 <- list()
    for (did in names(docs)) {
        doc <- docs[[did]]
        tdoc <- tokenize(doc)
        tdoc2 <- tokenize(doc, t)
        tdocs[[did]] <- tdoc
        tdocs2[[did]] <- tdoc2
    }

    tcorp <- tokenize(corp)
    checkEquals(documentViews(tcorp), tdocs, "documentViews")

    tcorp2 <- tokenize(corp, t)
    checkEquals(documentViews(tcorp2), tdocs2, "documentViews with tokenizer")
    
}
