\name{Corpus-class}
\docType{class}
\alias{Corpus-class}
\alias{applyToDocuments,Corpus,function-method}
\alias{applyToTokens,Corpus,function-method}
\alias{[<-,Corpus,character,ANY,Document-method}
\alias{[,Corpus,character-method}
\alias{df,Corpus-method}
\alias{documents<-,Corpus,list-method}
\alias{documents,Corpus-method}
\alias{filterDocuments,Corpus,function-method}
\alias{filterTokens,Corpus,function-method}
\alias{hasDocument,Corpus,character-method}
\alias{hasDocument,Corpus,Document-method}
\alias{idf,Corpus-method}
\alias{id<-,Corpus,character-method}
\alias{id,Corpus-method}
\alias{length,Corpus-method}
\alias{lowercase,Corpus-method}
\alias{removePunct,Corpus-method}
\alias{show,Corpus-method}
\alias{stem,Corpus,Stemmer,Tokenizer-method}
\alias{tag,Corpus,Tagger-method}
\alias{tokenize,Corpus,Tokenizer-method}

\title{Class "Corpus"}

\description{\code{Corpus} is a class for representing a collection of text in the form of \code{Document} objects.}

\section{Objects from the Class}{
    \code{Corpus} objects can be created by calls of the form 
    \code{Corpus("id", doclst)} where \code{doclst} is a \code{list} 
    of \code{Document} objects indexed by their ids. 

    \code{Corpus} objects can also be created by calls to the 
    \code{readCorpus} method.
}
\section{Slots}{
	 \describe{
    \item{\code{id}:}{A \code{character} identifier for this \code{Corpus}}
    \item{\code{documents}:}{A \code{list} of \code{Document} objects, indexed by the \code{Document} objects' ids}
  }
}
\section{Methods}{
  \describe{
    \item{applyToDocuments}{\code{signature(object = "Corpus", f = "function")}: Returns a new \code{Corpus} object containing \code{Document} objects obtained by applying the function \code{f} to each \code{Document} in the original \code{Corpus}. \code{f} should be a function that taks a \code{Document} object as an argument and returns a \code{Document} object.}
    \item{applyToTokens}{\code{signature(object = "Corpus", f = "function")}: Tokenizes the given \code{Corpus} and then applies the given function \code{f} to each token. Returns a \code{TokenizedCorpusView}.}
    \item{[<-}{\code{signature(x = "Corpus", i = "character", j = "ANY", value = "Document")}: Replaces the \code{Document} with the id \code{i} with \code{value}.}
    \item{[}{\code{signature(x = "Corpus", i = "character")}: Returns the \code{Document} in the given \code{Corpus} that has id equal to \code{i}.}
    \item{df}{\code{signature(object = "Corpus")}: Tokenizes this \code{Corpus} and returns an \code{integer} vector with the document frequency of each token.}
    \item{documents<-}{\code{signature(object = "Corpus", value = "list")}: Sets the \code{Document} objects in this \code{Corpus} to the given \code{list}.}
    \item{documents}{\code{signature(object = "Corpus")}: Returns a \code{list} of the \code{Document} objects in the given \code{Corpus}. The \code{list} is indexed by the \code{Document} objects' ids.}
    \item{filterDocuments}{\code{signature(object = "Corpus", f = "function", negate = "logical")}: Returns a new \code{Corpus} object containing only the \code{Document} objects on which \code{f} evaluates to \code{TRUE} (or \code{FALSE} if \code{negate} is set to \code{TRUE}).}
    \item{filterTokens}{\code{signature(object = "Corpus", f = "function")}: Tokenizes the given \code{Corpus} with the default \code{Tokenizer} and filters the tokens using the given function \code{f}. Returns a \code{TokenizedCorpusView}.}
    \item{hasDocument}{\code{signature(object = "Corpus", doc = "character")}: Returns \code{TRUE} if the given \code{Corpus} contains a \code{Document} with the given id.}
    \item{hasDocument}{\code{signature(object = "Corpus", doc = "Document")}: Returns \code{TRUE} if the given \code{Corpus} contains the given \code{Document}.}
    \item{idf}{\code{signature(object = "Corpus")}: Returns a \code{numeric} vector containing the idf values of the tokens in the given \code{Corpus}.}
    \item{id<-}{\code{signature(object = "Corpus", value = "character")}: Sets the id of the given \code{Corpus}.}
    \item{id}{\code{signature(object = "Corpus")}: Returns the id of the given \code{Corpus}.}
    \item{length}{\code{signature(x = "Corpus")}: Returns the number of \code{Document} objects in the given \code{Corpus}. }
    \item{lowercase}{\code{signature(x = "Corpus")}: Returns a new \code{Corpus} containing \code{Document} objects obtained by lowercasing the text in the given \code{Corpus}.}
    \item{removePunct}{\code{signature(object = "Corpus")}: Returns a new \code{Corpus} containing \code{Document} objects obtained by removing the punctuation in the text of the given \code{Corpus}.}
    \item{show}{\code{signature(object = "Corpus")}: Prints information about the given \code{Corpus}.}
    \item{stem}{\code{signature(object = "Corpus", stemmer = "Stemmer", tokenizer = "Tokenizer")}: ... }
    \item{tag}{\code{signature(object = "Corpus", tagger = "Tagger")}: Tokenizes the given \code{Corpus} with the default \code{Tokenizer}, and then tags the tokens using the given \code{Tagger}. Returns a \code{TaggedCorpusView}.}
    \item{tokenize}{\code{signature(object = "Corpus", tokenizer = "Tokenizer")}: Tokenizes the given \code{Corpus} with the given \code{Tokenizer} and returns a \code{TokenizedCorpusView}.}
	 }
}
\author{tfader@iq.harvard.edu}

\seealso{
	\code{\linkS4class{CorpusView}}
    \code{\linkS4class{Document}}
    \code{\link{readCorpus}}
}
\examples{
## Create a Corpus object manually
doc1 <- Document("d1", "Content 1")
doc2 <- Document("d2", "Content 2")
docList <- list(d1=doc1, d2=doc2)
corp1 <- Corpus("corp1", docList)
corp1

## Read a directory of files
dirPath <- system.file("samples/en", package="text2num")
corp2 <- readCorpus(dirPath)
corp2

## Select a document
corp2["sentence.txt"]

## Add a document
corp2["d1"] <- doc1

## Get a list of documents
docList2 <- documents(corp2)

}
\keyword{classes}
