\name{Document-class}
\docType{class}
\alias{Document-class}
\alias{applyToTokens,Document,function-method}
\alias{[<-,Corpus,character,ANY,Document-method}
\alias{content<-,Document,character-method}
\alias{content,Document-method}
\alias{filterTokens,Document,function-method}
\alias{hasDocument,Corpus,Document-method}
\alias{id<-,Document,character-method}
\alias{id,Document-method}
\alias{lowercase,Document-method}
\alias{removePunct,Document-method}
\alias{show,Document-method}
\alias{stem,Document,Stemmer,Tokenizer-method}
\alias{tag,Document,Tagger-method}
\alias{tokenize,Document,Tokenizer-method}

\title{Class "Document"}
\description{
    A class for representing text. 
}
\section{Objects from the Class}{
    Objects can be created by calls of the form 
    \code{Document("id", "content")} or \code{readDocument(source)}, where
    source is either a path to a file or a connection object.
}
\section{Slots}{
	 \describe{
    \item{\code{id}:}{A character identifier for this Document}
    \item{\code{content}:}{The character content of this Document}
  }
}
\section{Methods}{
  \describe{
    \item{applyToTokens}{\code{signature(object = "Document", f = "function")}: Tokenizes the given \code{Document} using the default \code{Tokenizer} and returns a \code{TokenizedDocumentView} object with the function \code{f} applied to the tokens}
    \item{content<-}{\code{signature(object = "Document", value = "character")}: Sets the content of this \code{Document}}
    \item{content}{\code{signature(object = "Document")}: Returns the content of this \code{Document}}
    \item{filterTokens}{\code{signature(object = "Document", f = "function")}: Tokenizes the given \code{Document} using the default \code{Tokenizer} and returns a \code{TokenizedDocumentView} with the tokens filtered by \code{f}}
    \item{id<-}{\code{signature(object = "Document", value = "character")}: Sets the id of the given \code{Document}}
    \item{id}{\code{signature(object = "Document")}: Returns the id of the given \code{Document}}
    \item{lowercase}{\code{signature(x = "Document")}: Returns a new \code{Document} with the same id but with lowercase content}
    \item{removePunct}{\code{signature(object = "Document")}: Returns a new \code{Document} with the same id and the punctuation marks stripped out of the content}
    \item{show}{\code{signature(object = "Document")}: Prints information about the given \code{Document}}
    \item{stem}{\code{signature(object = "Document", stemmer = "Stemmer", tokenizer = "Tokenizer")}: Returns a \code{TokenizedDocumentView} of this \code{Document} tokenized with the given \code{Tokenizer} and then stemmed using the given \code{Stemmer}}
    \item{tag}{\code{signature(object = "Document", tagger = "Tagger")}: Tags the given \code{Document} with the given \code{Tagger} and returns a \code{TaggedDocumentView}}
    \item{tokenize}{\code{signature(object = "Document", tokenizer = "Tokenizer")}: Tokenizes the given \code{Document} with the given \code{Tokenizer}}
	 }
}
\author{ tfader@iq.havard.edu }

\seealso{
    \code{\linkS4class{DocumentView}}
    \code{\link{readDocument}}
}
\examples{
    ## Create a new document
    doc <- Document("doc", "Some content")
    id(doc)
    content(doc)

    ## Change its id and content
    id(doc) <- "doc1"
    content(doc) <- "Some other content"

    ## Read a new document
    path <- system.file("samples/en/sentence.txt", package="text2num")
    sent <- readDocument(path)

    ## Tokenize a document
    doc.t <- tokenize(sent)
    tokens(doc.t)

    ## Stem a document
    doc.s <- stem(sent)
    tokens(doc.s)

}
\keyword{classes}
