\name{RegexTokenizer-class}
\docType{class}
\alias{RegexTokenizer-class}
\alias{matchToken<-,RegexTokenizer,logical-method}
\alias{matchToken,RegexTokenizer-method}
\alias{pattern<-,RegexTokenizer,ANY-method}
\alias{pattern,RegexTokenizer-method}
\alias{tokenize,character,RegexTokenizer-method}

\title{Class "RegexTokenizer"}
\description{A \code{Tokenizer} class used to tokenize text using regular expressions.}
\section{Objects from the Class}{
    Objects can be created by calls of the form 
    \code{RegexTokenizer(pattern=p, matchToken=l)}. \code{p} should
    be a regular expression and \code{l} should be a logical value.
    If \code{l} is set to \code{TRUE}, then \code{p} is used to match
    tokens. If \code{l} is set to \code{FALSE}, then \code{p} is used
    to match the gaps between tokens.

    The default values are \code{pattern="\\w+|[^\\w\\s]+"} and 
    \code{matchToken=TRUE}, which will tokenize text roughly into 
    words and punctuation marks.
}
\section{Slots}{
	 \describe{
    \item{\code{pattern}:}{A \code{character} regular expression}
    \item{\code{matchToken}:}{A \code{logical} value used to control whether \code{pattern} is used to match the tokens (\code{TRUE}) or the gaps between tokens (\code{FALSE})}
  }
}
\section{Extends}{
Class \code{"\linkS4class{Tokenizer}"}, directly.
}
\section{Methods}{
  \describe{
    \item{matchToken<-}{\code{signature(object = "RegexTokenizer", value = "logical")}: Sets whether the regular expression should be used to match tokens or gaps between tokens.}
    \item{matchToken}{\code{signature(object = "RegexTokenizer")}: Returns whether the regular expression should should be used to match tokens or gaps between tokens.}
    \item{pattern<-}{\code{signature(object = "RegexTokenizer", value = "ANY")}: Sets the regular expression pattern.}
    \item{pattern}{\code{signature(object = "RegexTokenizer")}: Returns the regular expression pattern.}
    \item{tokenize}{\code{signature(object = "character", tokenizer = "RegexTokenizer")}: Tokenizes the given \code{character} and returns a \code{character} vector of tokens. If \code{matchToken} is set to \code{TRUE}, each token will match the \code{pattern} slot of the given \code{RegexTokenizer}. If \code{matchToken} is \code{FALSE}, then the given \code{character} object will be split into tokens using substrings that match the \code{pattern} slot as boundaries.}
	 }
}
\author{tfader@iq.harvard.edu}
\seealso{
    \code{\link{tokenize}}
    \code{\linkS4class{Tokenizer}}
    \code{\linkS4class{TokenizedDocmentView}}
    \code{\linkS4class{TokenizedCorpusView}}
}
\examples{
## Splits into words
str <- "To be or not to be?"
rt1 <- RegexTokenizer(pattern="\\w+|[^\\w\\s]+", matchToken=TRUE)
tokenize(str, rt1)

## Splits on the word "be"
rt2 <- RegexTokenizer(pattern=" ?be ?", matchToken=FALSE)
tokenize(str, rt2)
}
\keyword{classes}
