\name{TaggedCorpusView-class}
\docType{class}
\alias{TaggedCorpusView-class}
\alias{documentTaggedTokenMatrix,TaggedCorpusView-method}
\alias{documentTagMatrix,TaggedCorpusView-method}
\alias{show,TaggedCorpusView-method}
\alias{unique,TaggedCorpusView-method}
\alias{uniqueTags,TaggedCorpusView-method}
\alias{uniqueTokens,TaggedCorpusView-method}

\title{Class "TaggedCorpusView"}
\description{A representation of a corpus of text that has been tokenized and each token is assigned a tag (e.g., part-of-speech).}
\section{Objects from the Class}{
    In general, \code{TaggedCorpusView} objects should not be constructed
    directly unless you are writing code to extend this package. Instead,
    they can be obtained from an existing \code{Corpus} object by calling
    \code{tag(corp)}.

    If you are extending the package, the constructor function 
    \code{TaggedCorpusView(corpus, taggedDocumentViews)} can be used.
}
\section{Slots}{
	 \describe{
    \item{\code{uniqueTags}:}{A \code{character} vector of unique tags}
    \item{\code{uniqueTokenTags}:}{A \code{character} vector of unique "token/tag" frequencies}}
    \item{\code{documentTagMatrix}:}{A matrix containing the frequencies of tags in each document}
    \item{\code{documentTokenTagMatrix}:}{A matrix containing the frequencies of "token/tag" in each document}
    \item{\code{corpus}:}{The underlying \code{Corpus} object}
    \item{\code{uniqueTokens}:}{A \code{character} vector of unique tokens}
    \item{\code{documentTokenMatrix}:}{A matrix containing the frequencies of tokens in each document}
    \item{\code{tokenizedDocumentViews}:}{A \code{list} of the underlying \code{TokenizedDocumentView} objects}
  }
}
\section{Extends}{
Class \code{"\linkS4class{TokenizedCorpusView}"}, directly.
Class \code{"\linkS4class{CorpusView}"}, by class "TokenizedCorpusView", distance 2.
}
\section{Methods}{
  \describe{
    \item{documentTaggedTokenMatrix}{\code{signature(object = "TaggedCorpusView")}: Returns a matrix of "token/tag" frequencies in each document.}
    \item{documentTagMatrix}{\code{signature(object = "TaggedCorpusView")}: Returns a matrix of tag frequencies in each document.}
    \item{show}{\code{signature(object = "TaggedCorpusView")}: Prints information about the given \code{TaggedCorpusView}.}
    \item{unique}{\code{signature(x = "TaggedCorpusView")}: Returns the unique tokens in the given \code{TaggedCorpusView}.}
    \item{uniqueTags}{\code{signature(object = "TaggedCorpusView")}: Returns the unique tags in the given \code{TaggedCorpusView}.}
    \item{uniqueTokens}{\code{signature(x = "TaggedCorpusView")}: Returns the unique tokens in the given \code{TaggedCorpusView}.}
	 }
}
\author{tfader@iq.harvard.edu}
\seealso{
    \code{\link{tag}}
    \code{\linkS4class{Tagger}}
    \code{\linkS4class{TaggedDocumentView}}
    \code{\linkS4class{Corpus}}
    \code{\linkS4class{TokenizedCorpusView}}
}
\examples{
## TODO: Write TCV examples
}
\keyword{classes}
