\name{TaggedDocumentView-class}
\docType{class}
\alias{TaggedDocumentView-class}
\alias{[,TaggedDocumentView,ANY-method}
\alias{freqTable,TaggedDocumentView-method}
\alias{hasTaggedToken,character,character,TaggedDocumentView-method}
\alias{hasTag,character,TaggedDocumentView-method}
\alias{hasToken,character,TaggedDocumentView-method}
\alias{show,TaggedDocumentView-method}
\alias{tagFreqTable,TaggedDocumentView-method}
\alias{taggedTokens,TaggedDocumentView-method}
\alias{tags,TaggedDocumentView-method}
\alias{tokenFreqTable,TaggedDocumentView-method}
\alias{unique,TaggedDocumentView-method}
\alias{uniqueTags,TaggedDocumentView-method}
\alias{uniqueTokens,TaggedDocumentView-method}

\title{Class "TaggedDocumentView"}
\description{A representation of text that has been tokenized and each token is assigned a tag (e.g., part-of-speech).}
\section{Objects from the Class}{
    In general, \code{TaggedDocumentView} objects should not be
    constructed directly unless you are writing code to extend this
    package. Instead, they can be obtained from an existing
    \code{Document} object by calling \code{tag(doc)}.

    If you are extending the package, the constructor function
    \code{TaggedDocumentView(document, tokens, tags, tokenFreqTable, tagFreqTable, tokenTagFreqTable)}
    can be used.
}
\section{Slots}{
	 \describe{
    \item{\code{tokens}:}{A \code{character} vector of tokens}
    \item{\code{tags}:}{A \code{character} vector of tags given to each entry in \code{tokens} }
    \item{\code{tagFreqTable}:}{A \code{table} of tag frequencies}
    \item{\code{uniqueTags}:}{A \code{character} vector of unique tags}
    \item{\code{tokenTagFreqTable}:}{A \code{table} of "token/tag" frequencies}
    \item{\code{uniqueTokenTags}:}{A \code{character} vector of unique "token/tag" pairs}
    \item{\code{tokenFreqTable}:}{A \code{table} of token frequencies}
    \item{\code{uniqueTokens}:}{A \code{character} vector of unique tokens}
    \item{\code{document}:}{A copy of the \code{Document} object that this is a view of}
  }
}
\section{Extends}{
Class \code{"\linkS4class{TokenizedDocumentView}"}, directly.
Class \code{"\linkS4class{DocumentView}"}, by class "TokenizedDocumentView", distance 2.
}
\section{Methods}{
  \describe{
    \item{[}{\code{signature(x = "TaggedDocumentView", i = "ANY")}: Returns the token/tag pair at index \code{i}.}
    \item{freqTable}{\code{signature(object = "TaggedDocumentView")}: Returns a \code{table} of token frequencies.}
    \item{hasTaggedToken}{\code{signature(token = "character", tag = "character", container = "TaggedDocumentView")}: Returns \code{TRUE} if the given token, tag pair occurs in the given \code{TaggedDocumentView}.}
    \item{hasTag}{\code{signature(object = "character", container = "TaggedDocumentView")}: Returns \code{TRUE} if the given tag occurs in the given \code{TaggedDocumentView}.}
    \item{hasToken}{\code{signature(object = "character", container = "TaggedDocumentView")}: Returns \code{TRUE} if the given token occurs in the given \code{TaggedDocumentView}.}
    \item{show}{\code{signature(object = "TaggedDocumentView")}: Prints information about the given \code{TaggedDocumentView}.}
    \item{tagFreqTable}{\code{signature(object = "TaggedDocumentView")}: Returns a \code{table} of tag frequencies.}
    \item{taggedTokens}{\code{signature(object = "TaggedDocumentView")}: Returns a \code{character} vector of "tag/token" pairs.}
    \item{tags}{\code{signature(object = "TaggedDocumentView")}: Returns a \code{character} vector of the tags.}
    \item{tokenFreqTable}{\code{signature(object = "TaggedDocumentView")}: Returns a \code{table} of token frequencies.}
    \item{unique}{\code{signature(x = "TaggedDocumentView")}: Returns a \code{character} vector of unique "token/tag" pairs occuring in the given \code{TaggedDocumentView}.}
    \item{uniqueTags}{\code{signature(object = "TaggedDocumentView")}: Returns a \code{character} vector of the unique tags.}
    \item{uniqueTokens}{\code{signature(x = "TaggedDocumentView")}: Returns a \code{character} vector of the unique tokens.}
	 }
}
\author{tfader@iq.harvard.edu}

\seealso{
    \code{\link{tag}}
    \code{\linkS4class{Tagger}}
    \code{\linkS4class{TaggedCorpusView}}
    \code{\linkS4class{Document}}
    \code{\linkS4class{TokenizedDocumentView}}
}
\examples{
## TODO: Write TDV examples
}
\keyword{classes}
