\name{TokenizedCorpusView-class}
\docType{class}
\alias{TokenizedCorpusView-class}
\alias{applyToTokens,TokenizedCorpusView,function-method}
\alias{df,TokenizedCorpusView-method}
\alias{documentTokenMatrix,TokenizedCorpusView-method}
\alias{documentTokenTfidfMatrix,TokenizedCorpusView-method}
\alias{documentViews,TokenizedCorpusView-method}
\alias{filterTokensDf,TokenizedCorpusView-method}
\alias{filterTokens,TokenizedCorpusView,function-method}
\alias{has,character,TokenizedCorpusView-method}
\alias{idf,TokenizedCorpusView-method}
\alias{lowercase,TokenizedCorpusView-method}
\alias{removePunct,TokenizedCorpusView-method}
\alias{show,TokenizedCorpusView-method}
\alias{stem,TokenizedCorpusView,Stemmer,Tokenizer-method}
\alias{tag,TokenizedCorpusView,Tagger-method}
\alias{unique,TokenizedCorpusView-method}

\title{Class "TokenizedCorpusView"}
\description{View of a \code{Corpus} as a collection of \code{TokenizedDocumentView} objects.}
\section{Objects from the Class}{
    In general, \code{TokenizedCorpusView} objects should not be 
    constructed directly unless you are writing code to extend this 
    package. Instead, they can be obtained from an existing
    \code{Corpus} object by calling \code{tokenize(corp)}.

    If you are extending the package, use the constructor function 
    \code{TokenizedCorpusView(corp, tokenizedDocumentViews)}, where
    \code{corp} is a \code{Corpus} object and \code{tokenizedDocumentViews}
    is a list of \code{TokenizedDocumentView} objects, indexed by their
    ids.
}
\section{Slots}{
	 \describe{
    \item{\code{corpus}:}{The underlying \code{Corpus} object}
    \item{\code{uniqueTokens}:}{A \code{character} vector of unique tokens in the corpus}
    \item{\code{documentTokenMatrix}:}{A matrix containing the frequency of tokens in documents}
    \item{\code{tokenizedDocumentViews}:}{A \code{list} of \code{TokenizedDocumentView} objects indexed by their ids}
  }
}
\section{Extends}{
Class \code{"\linkS4class{CorpusView}"}, directly.
}
\section{Methods}{
  \describe{
    \item{applyToTokens}{\code{signature(object = "TokenizedCorpusView", f = "function")}: Applies the function \code{f} to the tokens of the underlying \code{TokenizedDocumentView} objects and returns a new \code{TokenizedCorpusView}.}
    \item{df}{\code{signature(object = "TokenizedCorpusView")}: Returns a vector containing the document frequencies of each token.}
    \item{documentTokenMatrix}{\code{signature(object = "TokenizedCorpusView")}:Returns a matrix where the (i,j)-th entry is the frequency of the jth token in the ith document.}
    \item{documentTokenTfidfMatrix}{\code{signature(object = "TokenizedCorpusView")}: Returns a matrix where the (i,j)-th entry is the frequency of the jth token in the ith document, multiplied by the idf of the jth token.}
    \item{documentViews}{\code{signature(object = "TokenizedCorpusView")}: Returns a list containing the underlying \code{TokenizedDocumentView} objects.}
    \item{filterTokensDf}{\code{signature(object = "TokenizedCorpusView")}: Filters the tokens from the given \code{TokenizedCorpusView} based on their document frequency.}
    \item{filterTokens}{\code{signature(object = "TokenizedCorpusView", f = "function", negate = "logical")}: Returns a new \code{TokenizedCorpusView} containing the tokens that \code{f} returns \code{TRUE} for (or \code{FALSE} if the parameter \code{negate} is set to \code{TRUE}).}
    \item{has}{\code{signature(object = "character", container = "TokenizedCorpusView")}: Returns \code{TRUE} if the given \code{TokenizedCorpusView} contains the given token.}
    \item{idf}{\code{signature(object = "TokenizedCorpusView")}: Returns a vector of idf values for the tokens in the given \code{TokenizedCorpusView}.}
    \item{lowercase}{\code{signature(x = "TokenizedCorpusView")}: Returns a new \code{TokenizedCorpusView} containing lowercase versions of the tokens from the given \code{TokenizedCorpusView}.}
    \item{removePunct}{\code{signature(object = "TokenizedCorpusView")}: Returns a new \code{TokenizedCorpusView} object containing only the non-punctuation tokens from the given \code{TokenizedCorpusView}.}
    \item{show}{\code{signature(object = "TokenizedCorpusView")}: Prints information about the given \code{TokenizedCorpusView}.}
    \item{stem}{\code{signature(object = "TokenizedCorpusView", stemmer = "Stemmer", tokenizer = "Tokenizer")}: Returns a new \code{TokenizedCorpusView} created by applying the given \code{Stemmer} to each token in the given \code{TokenizedCorpusView}.}
    \item{tag}{\code{signature(object = "TokenizedCorpusView", tagger = "Tagger")}: Returns a \code{TaggedCorpusView} created by tagging the given \code{TokenizedCorpusView} with the given \code{Tagger}.}
    \item{unique}{\code{signature(x = "TokenizedCorpusView")}: Returns the unique tokens of the give \code{TokenizedCorpusView} as a \code{character} vector.}
	 }
}
\author{tfader@iq.harvard.edu}

\seealso{
    \code{\link{tokenize}}
    \code{\linkS4class{Tokenizer}}
    \code{\linkS4class{TokenizedDocumentView}}
    \code{\linkS4class{Corpus}}
    \code{\linkS4class{CorpusView}}
}
\examples{
## Reads into a Corpus
path <- system.file("samples/en", package="text2num")
corp <- readCorpus(path)

## Makes a TokenizedCorpusView
corp.t <- tokenize(corp)
corp.t

## Various ways to acccess the underlying tokens
tokens(corp.t)
unique(corp.t)
M <- documentTokenMatrix(corp.t)
M[,c("the", "of", "be")]
}
\keyword{classes}
