\name{TokenizedDocumentView-class}
\docType{class}
\alias{TokenizedDocumentView-class}
\alias{applyToTokens,TokenizedDocumentView,function-method}
\alias{[,TokenizedDocumentView,ANY-method}
\alias{filterTokens,TokenizedDocumentView,function-method}
\alias{freqTable,TokenizedDocumentView-method}
\alias{freq,character,TokenizedDocumentView-method}
\alias{has,character,TokenizedDocumentView-method}
\alias{lowercase,TokenizedDocumentView-method}
\alias{removePunct,TokenizedDocumentView-method}
\alias{show,TokenizedDocumentView-method}
\alias{stem,TokenizedDocumentView,Stemmer,Tokenizer-method}
\alias{tag,TokenizedDocumentView,Tagger-method}
\alias{tokens,TokenizedDocumentView-method}
\alias{unique,TokenizedDocumentView-method}

\title{Class "TokenizedDocumentView"}
\description{View of a \code{Document} as a sequence of tokens.}
\section{Objects from the Class}{
    In general, \code{TokenizedDocumentView} objects should not be
    constructed directly unless you are writing code to extend this
    package. Instead, they can be obtained from an existing 
    \code{Document} object by calling \code{tokenize(doc)}.

    If you are extending the package, the constructor function
    \code{TokenizedDocumentView(document, tokens, tokenFreqTable)}
    can be used.
}
\section{Slots}{
	 \describe{
    \item{\code{tokens}:}{A \code{character} vector of tokens}
    \item{\code{tokenFreqTable}:}{A \code{table} containing the frequencies of tokens}
    \item{\code{uniqueTokens}:}{A \code{character} vector of unique tokens}
    \item{\code{document}:}{A copy of the \code{Document} object that this is a view of}
  }
}
\section{Extends}{
    Class \code{"\linkS4class{DocumentView}"}, directly.
}
\section{Methods}{
  \describe{
    \item{applyToTokens}{\code{signature(object = "TokenizedDocumentView", f = "function")}: Applies the function \code{f} to the tokens of the given \code{TokenizedDocumentView} and returns them as a new \code{TokenizedDocumentView}.}
    \item{[}{\code{signature(x = "TokenizedDocumentView", i = "ANY")}: Returns the token at index \code{i}.}
    \item{filterTokens}{\code{signature(object = "TokenizedDocumentView", f = "function", negate="logical")}: Returns a new \code{TokenizedDocumentView} containing the tokens that \code{f} returns \code{TRUE} for (or \code{FALSE} if the parameter \code{negate} is set to \code{TRUE}).}
    \item{filterTokensRegex}{\code{signature(object = "TokenizedDocumentView", pattern = "character", negate="logical")}: Returns a new \code{TokenizedDocumentView} containing the tokens that match the given regular expression (or that don't match it if the parameter \code{negate} is set to \code{TRUE}).}
    \item{freqTable}{\code{signature(object = "TokenizedDocumentView")}: Returns a \code{table} object containing the frequencies of the tokens in the given \code{TokenizedDocumentView}.}
    \item{freq}{\code{signature(object = "character", container = "TokenizedDocumentView")}: Returns the frequency of the given token in the given \code{TokenizedDocumentView}.}
    \item{has}{\code{signature(object = "character", container = "TokenizedDocumentView")}: Returns \code{TRUE} if the given \code{TokenizedDocumentView} contains the given token.}
    \item{lowercase}{\code{signature(x = "TokenizedDocumentView")}: Returns a new \code{TokenizedDocumentView} containing the lowercase versions of the tokens in the givne \code{TokenizedDocumentView}.}
    \item{removePunct}{\code{signature(object = "TokenizedDocumentView")}: Returns a new \code{TokenizedDocumentView} containing all non-punctuation tokens from the given \code{TokenizedDocumentView}.}
    \item{show}{\code{signature(object = "TokenizedDocumentView")}: Prints information about the given \code{TokenizedDocumentView}.}
    \item{stem}{\code{signature(object = "TokenizedDocumentView", stemmer = "Stemmer", tokenizer = "Tokenizer")}: Returns a new \code{TokenizedDocumentView} created by applying the given \code{Stemmer} to each token in the given \code{TokenizedDocumentView}.}
    \item{tag}{\code{signature(object = "TokenizedDocumentView", tagger = "Tagger")}: Returns a \code{TaggedDocumentView} created by tagging the given \code{TokenizedDocumentView} with the given \code{Tagger}.}
    \item{tokens}{\code{signature(object = "TokenizedDocumentView")}: Returns the tokens of the given \code{TokenizedDocumentView} as a \code{character} vector.}
    \item{unique}{\code{signature(x = "TokenizedDocumentView")}: Returns the unique tokens of the given \code{TokenizedDocumentView} as a \code{character} vector.}
	 }
}
\author{tfader@iq.harvard.edu}

\seealso{
    \code{\link{tokenize}}
    \code{\linkS4class{Tokenizer}}
    \code{\linkS4class{TokenizedCorpusView}}
    \code{\linkS4class{Document}}
    \code{\linkS4class{DocumentView}}
}
\examples{
## Reads into a Document
path <- system.file("samples/en/sentence.txt", package="text2num")
doc <- readDocument(path)

## Makes a TokenizedDocumentView
doc.t <- tokenize(doc)
doc.t

## Various ways to access the underlying tokens
tokens(doc.t)
doc.t[c(1,3,5)]
unique(doc.t)
freqTable(doc.t)

## Apply functions to tokens 
be2bee <- function(x) ifelse(x == "be", "bee", x)
doc.bee <- applyToTokens(doc.t, be2bee) 
tokens(doc.bee)

## Filter tokens
isLong <- function(x) nchar(x) > 2
doc.long <- filterTokens(doc.t, isLong)
tokens(doc.long)
doc.short <- filterTokens(doc.t, isLong, negate=TRUE)
tokens(doc.short)
doc.nop <- removePunct(doc.t)
tokens(doc.nop)
doc.nob <- filterTokensRegex(doc.t, "b", negate=TRUE)
tokens(doc.nob)

}
\keyword{classes}
