#include <ext/hash_map>
#include <string>
#include <Rinternals.h>

using namespace __gnu_cxx;

static SEXP HASH_TYPE_TAG;

struct eqstr
{
  bool operator() (const char* s1, const char* s2) const
  {
    return strcmp(s1, s2) == 0;
  }
};

typedef hash_map<const char*, SEXP, hash<const char*>, eqstr> myhash;

extern "C" {

  SEXP HASH_init ()
  {
    HASH_TYPE_TAG = install("HASH_TYPE_TAG");

    return R_NilValue;
  }

  SEXP HASH_delete (SEXP hashptr)
  {
    myhash* ptr = (myhash*) R_ExternalPtrAddr(hashptr);

    // First unprotect the sexps populating the hash
    int size = (*ptr).size();
    Rprintf("%d\n", size);

    // Now delete the actual C++ object and clear the external pointer
    delete ptr;
    R_ClearExternalPtr(hashptr);

    Rprintf("Destructor called\n");

    return R_NilValue;
  }

  SEXP HASH_new ()
  {
    myhash* new_hash = new myhash;

    SEXP hashptr;
    PROTECT(hashptr = R_MakeExternalPtr(new_hash, HASH_TYPE_TAG, R_NilValue));
    R_RegisterCFinalizerEx(hashptr, (R_CFinalizer_t) HASH_delete, TRUE);
    UNPROTECT(1);

    return hashptr;
  }

  SEXP HASH_insert (SEXP hashptr, SEXP key, SEXP value)
  {
    myhash* ptr = (myhash*) R_ExternalPtrAddr(hashptr);

    const char* k = CHAR(STRING_ELT(key, 0));
    SEXPREC hard_copy = *value;

    (*ptr)[k] = hard_copy;

    return R_NilValue;;
  }

  SEXP HASH_fetch (SEXP hashptr, SEXP key)
  {
    myhash* ptr = (myhash*) R_ExternalPtrAddr(hashptr);

    const char* k = CHAR(STRING_ELT(key, 0));

    if ((*ptr).find(k) != (*ptr).end()) {
      SEXP retval;
      retval = (*ptr)[k];
      return retval;
    } else 
      return R_NilValue;
  }

  SEXP HASH_size (SEXP hashptr)
  {
    myhash* ptr = (myhash*) R_ExternalPtrAddr(hashptr);

    SEXP ans;
    PROTECT(ans = allocVector(REALSXP, 1));
    REAL(ans)[0] = (*ptr).size();
    UNPROTECT(1);

    return ans;
  }

} // extern "C" 

