setClass("myclass", representation(vec="vector"), prototype(vec = vector()))

setMethod("[", "myclass", function(x, i, j, drop) {
  if (!missing(j)) 
    warning("ignored second argument to []")
  return(x@vec[i])
})

setReplaceMethod("[", "myclass", function(x, i, j, value) {
  if (!missing(j)) 
    warning("ignored second argument to []")

  x@vec[i] <- value
  return(x)
})


# Here's a quick and dirty reference setup, using a private
# environment.  Perhaps scalable to production code, but seems a tad
# ugly for that.  Also, dereferencing overhead may be substantial, so
# may just trade faster updates of large objects for slower accesses
# across the board (and slower updates for small objects).  Would have
# to fix evaluations where indices passed in are expressions
.myenv <- new.env()

# A counter closure, no need for serious OO here
.counter <- function (start = 0, inc = TRUE) {
  cnt <- start

  function () {
    cur <- cnt
    if (inc)
      cnt <<- cnt + 1
    else
      cnt <<- cnt - 1
    cur
  }
}

# Functions for creating document/corpus ids.  At the moment, it is
# implemented as a simple counter.
.myNextId <- .counter()

setClass("myrefclass", representation(vecref="character"))

setMethod("initialize", "myrefclass", function(.Object) {
  .Object@vecref <- paste("myobj", .myNextId(), sep="") 
  assign(.Object@vecref, vector(), envir=.myenv)
  .Object
})

setMethod("[", "myrefclass", function(x, i, j, drop) {
  if (!missing(j)) 
    warning("ignored second argument to []")
  
  
  assign("i", i, envir=.myenv)
  res = eval(parse(text=paste(x@vecref, "[i]", sep="")), 
              envir=.myenv)
  rm(i, envir=.myenv)
  return(res)
})

# Is there some way we can get around using the whole replacemethod
# thing here?  If we could get R not to copy the object, that would be
# nice, since we don't need to.
setReplaceMethod("[", "myrefclass", function(x, i, j, value) {
  if (!missing(j)) 
    warning("ignored second argument to []")

  #print(paste(x@vecref, "[", i, "] <- ", value, sep=""))
  assign("i", i, envir=.myenv)
  assign("value", value, envir=.myenv)
  eval(parse(text=paste(x@vecref, "[i] <- value", sep="")), envir=.myenv)
  rm(i, value, envir=.myenv)
  return(x)
})

n <- 100000000

print("no refs")
x<-new("myclass")
print("a")
x[1:n]<-10
print("b")
x[5]<-6

print("refs")
y<-new("myrefclass")
print("a")
y[1:n]<-10  # this is cheap shit to see if it will work
print("b")
y[5]<-6
