#ifndef __PUNKT_WORD_TOKENIZER_H__
#define __PUNKT_WORD_TOKENIZER_H__

#include <Python.h>
#include <Rinternals.h>
#include <Rdefines.h>
#include "embed_nltk.h"

/*
 * Called directly from R using the .Call interface.
 */
inline SEXP construct_punkt_word_tokenizer ()
{
  /* Declarations */
  SEXP ptr; 
  PyObject *argtuple, *tokenizer;
  
  /* Stick the training data and backoff into a tuple to pass */
  argtuple = PyTuple_New(0);

  /* Create the tagger and get an R external pointer to it. */
  ptr = construct_python_object(nltk_punkt_pnt(), argtuple, 
      "PunktWordTokenizer", destruct_python_object);
  
  UNPROTECT(1); // unprotect the ptr object
  return ptr;
}

/* Maybe move to a tokenize.h, as need arises */
inline SEXP
tokenize (SEXP ptr, SEXP r_string)
{
  PyObject *string, *tokenizer, *tokens, *funcname;
  SEXP r_tokens;
  
  /* Convert to a python string */
  string = PyString_FromString(CHAR(STRING_ELT(r_string, 0)));

  /* Grab tokenizer from external pointer */
  tokenizer = (PyObject*) R_ExternalPtrAddr(ptr);
  if (tokenizer == NULL)
    error("Lookup table address is invalid");
  
  /* Call the tokenizers's tokenize method */
  funcname = PyString_FromString("tokenize");
  tokens = PyObject_CallMethodObjArgs(tokenizer, funcname, string);
  Py_DECREF(funcname); /* cleaning */
  Py_DECREF(string);            /* up */

  /* Convert back to R */
  r_tokens = p2r_token_list(tokens); // protects r_tokens
  Py_DECREF(tokens); // we're done with tokens

  /* Unprotect r_tokens and return */
  UNPROTECT(1);
  return r_tokens;
}

#endif /* __PUNKT_WORD_TOKENIZER_H__ */
