#include <Python.h>
#include <Rinternals.h>
#include <Rdefines.h>
#include "embed_nltk.h"
#include "tagger.h"

/* Constructs a regexp tagger from a training list and returns the
 * address of the tagger object.  Takes a sequence of token-tag pairs
 * as an R list of lists where each sublist is a pair containing a
 * token and a tag.  Also takes the external pointer of a backoff
 * tagger, or NULL if no backoff tagger is to be used.
 *
 * Called directly from R using the .Call interface.
 */
inline SEXP 
construct_regexp_tagger (SEXP r_regexp_list, SEXP r_backoff) 
{ 
  /* Declarations */
  SEXP ptr;
  PyObject *regexp_list, *argtuple, *constructor, *tagger, *backoff;
  
  /* Transform the passed in data to the correct format, slightly
   * abusing the r2p_tagged_token_list function. */
  regexp_list = r2p_tagged_token_list(r_regexp_list);

  /* Debug code: PyObject_Print(regexp_list, stdout, 0); */

  /* Get the backoff, if there is one */
  backoff = get_backoff(r_backoff);

  /* Stick the training data and backoff into a tuple to pass */
  argtuple = PyTuple_New(2);
  PyTuple_SetItem(argtuple, 0, regexp_list);/* steals train_list ref */
  Py_INCREF(backoff); /*XXX SetItem steals...think this is necessary? */
  PyTuple_SetItem(argtuple, 1, backoff);

  /* Create the tagger and get an R external pointer to it. */
  ptr = construct_python_object(nltk_tag_pnt(), argtuple, 
      "RegexpTagger", destruct_python_object);
  
  UNPROTECT(1); // unprotect the ptr object
  return ptr;
}
