#include <Python.h>
#include <Rinternals.h>
#include <Rdefines.h>
#include "embed_nltk.h"
#include "tagger.h"

/* Constructs a trigram tagger from a training list and returns the
 * address of the tagger object.  Takes a sequence of sentences as an
 * R nested list, where each sublist is a sentence, and each
 * sub-sublist is a token-tag pair.  Also takes the external pointer
 * of a backoff tagger, or any logical (NA by convention) if no
 * backoff tagger is to be used, and a cutoff integer.
 *
 * Called directly from R using the .Call interface.
 */
inline SEXP construct_trigram_tagger (SEXP raw_train_list, SEXP
    r_backoff, SEXP r_cutoff) { 
  /* Declarations */
  SEXP ptr; PyObject *train_list, *argtuple, *backoff;
  
  /* Transform the passed in data to the correct format. */
  train_list = r2p_tagged_token_sentences(raw_train_list);

  /* Debug code: PyObject_Print(train_list, stdout, 0); */

  /* Get the backoff, if there is one */
  backoff = get_backoff(r_backoff);

  /* Stick the training data and backoff into a tuple to pass */
  argtuple = PyTuple_New(4);
  PyTuple_SetItem(argtuple, 0, train_list);/* steals train_list ref */
  PyTuple_SetItem(argtuple, 1, Py_None); /* model param */
  Py_INCREF(backoff); /*XXX SetItem steals...think this is necessary? */
  PyTuple_SetItem(argtuple, 2, backoff);
  PyTuple_SetItem(argtuple, 3, PyInt_FromLong((long)INTEGER(r_cutoff)));

  /* Create the tagger and get an R external pointer to it. */
  ptr = construct_python_object(nltk_tag_pnt(), argtuple, 
      "TrigramTagger", destruct_python_object);
  
  UNPROTECT(1); // unprotect the ptr object
  return ptr;
}
